Index: gm/bitmaprect.cpp |
diff --git a/gm/bitmaprect.cpp b/gm/bitmaprect.cpp |
index aa71f48eb09ae115f82b0388ff40bcd83f424086..ff52c15e5d9963cf570ced85c7c0a284c2b8c0ef 100644 |
--- a/gm/bitmaprect.cpp |
+++ b/gm/bitmaprect.cpp |
@@ -70,7 +70,8 @@ protected: |
canvas->drawBitmap(bitmap, 0, 0, &paint); |
if (!fUseIRect) { |
- canvas->drawBitmapRectToRect(bitmap, &srcR, dstR, &paint); |
+ canvas->drawBitmapRect(bitmap, &srcR, dstR, &paint, |
+ SkCanvas::kStrict_SrcRectConstraint); |
} else { |
canvas->drawBitmapRect(bitmap, &src[i], dstR, &paint); |
} |
@@ -110,7 +111,7 @@ static void make_3x3_bitmap(SkBitmap* bitmap) { |
} |
} |
// This GM attempts to make visible any issues drawBitmapRectToRect may have |
// with partial source rects. In this case the eight pixels on the border |
// should be half the width/height of the central pixel, i.e.: |
// __|____|__ |
@@ -110,7 +111,7 @@ static void make_3x3_bitmap(SkBitmap* bitmap) { |
} |
} |
-// This GM attempts to make visible any issues drawBitmapRectToRect may have |
+// This GM attempts to make visible any issues drawBitmapRect may have |
// with partial source rects. In this case the eight pixels on the border |
// should be half the width/height of the central pixel, i.e.: |